@@ -536,6 +536,9 @@ INVALIDPARAMETERVALUE_VPNCONNHEALTHCHECKIPCONFLICT = 'InvalidParameterValue.VpnC
 # SPD规则源目IP有重叠。
 INVALIDPARAMETERVALUE_VPNCONNSPDCIDRCONFLICT = 'InvalidParameterValue.VpnConnSpdCidrConflict'
 
+# VPN网关路由参数重复。
+INVALIDPARAMETERVALUE_VPNGATEWAYROUTEDUPLICATE = 'InvalidParameterValue.VpnGatewayRouteDuplicate'
+
 # 参数Zone的值与CDC所在Zone冲突。
 INVALIDPARAMETERVALUE_ZONECONFLICT = 'InvalidParameterValue.ZoneConflict'
 
@@ -842,6 +845,9 @@ UNSUPPORTEDOPERATION_CCNORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.CcnO
 # 当前路由与已有路由的CIDR重叠，仅能开启其中一条路由。
 UNSUPPORTEDOPERATION_CCNROUTECIDROVERLAP = 'UnsupportedOperation.CcnRouteCidrOverlap'
 
+# 云联网路由重叠功能不支持关闭
+UNSUPPORTEDOPERATION_CCNROUTEOVERLAPFLAGDISABLENOTSUPPORTED = 'UnsupportedOperation.CcnRouteOverlapFlagDisableNotSupported'
+
 # 指定的路由表不存在。
 UNSUPPORTEDOPERATION_CCNROUTETABLENOTEXIST = 'UnsupportedOperation.CcnRouteTableNotExist'
 
@@ -893,6 +899,9 @@ UNSUPPORTEDOPERATION_DELDEFAULTROUTE = 'UnsupportedOperation.DelDefaultRoute'
 # 禁止删除已关联子网的路由表。
 UNSUPPORTEDOPERATION_DELROUTEWITHSUBNET = 'UnsupportedOperation.DelRouteWithSubnet'
 
+# 当前云联网存在二层加速通道不支持删除。
+UNSUPPORTEDOPERATION_DELETECCNEXISTCCNEXPRESSCONNECT = 'UnsupportedOperation.DeleteCcnExistCcnExpressConnect'
+
 # VPN通道状态为更新中/销毁中/创建中，不支持此操作。
 UNSUPPORTEDOPERATION_DELETEVPNCONNINVALIDSTATE = 'UnsupportedOperation.DeleteVpnConnInvalidState'
 
@@ -929,6 +938,12 @@ UNSUPPORTEDOPERATION_ENDPOINTMISMATCHENDPOINTSERVICECDCID = 'UnsupportedOperatio
 # 终端节点服务本身不能是终端节点。
 UNSUPPORTEDOPERATION_ENDPOINTSERVICE = 'UnsupportedOperation.EndPointService'
 
+# 存在云联网自定义路由表不允许删除该云联网
+UNSUPPORTEDOPERATION_EXISTCCNCUSTOMROUTETABLESNOTSUPPORTDELETECCN = 'UnsupportedOperation.ExistCcnCustomRouteTablesNotSupportDeleteCcn'
+
+# 存在云联网关联实例不允许删除云联网
+UNSUPPORTEDOPERATION_EXISTCCNINSTANCESNOTSUPPORTDELETECCN = 'UnsupportedOperation.ExistCcnInstancesNotSupportDeleteCcn'
+
 # 指定ResourceId对应的流日志已经创建
 UNSUPPORTEDOPERATION_FLOWLOGINSTANCEEXISTED = 'UnsupportedOperation.FlowLogInstanceExisted'
 
@@ -1283,6 +1298,9 @@ UNSUPPORTEDOPERATION_VPCPEERINVALIDSTATECHANGE = 'UnsupportedOperation.VpcPeerIn
 # 该账不能发起操作。
 UNSUPPORTEDOPERATION_VPCPEERPURVIEWERROR = 'UnsupportedOperation.VpcPeerPurviewError'
 
+# VPN SPD通道不支持配置健康检查
+UNSUPPORTEDOPERATION_VPNCONNCIDRNOTSUPPORTEDHEALTHCHECK = 'UnsupportedOperation.VpnConnCidrNotSupportedHealthCheck'
+
 # 当前通道为非可用状态，不支持该操作。
 UNSUPPORTEDOPERATION_VPNCONNINVALIDSTATE = 'UnsupportedOperation.VpnConnInvalidState'
 
@@ -1307,6 +1325,12 @@ UNSUPPORTEDOPERATION_VPNUNSUPPORTEDMODIFYBGPASN = 'UnsupportedOperation.VpnUnsup
 # VPN未配置BGP ASN。
 UNSUPPORTEDOPERATION_VPNUNSUPPORTEDNOTEXISTBGPASN = 'UnsupportedOperation.VpnUnsupportedNotExistBgpAsn'
 
+# 3.1以下版本VPN网关不支持配置ecmp路由
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDROUTEECMPFORCVMVPN = 'UnsupportedOperation.VpnUnsupportedRouteEcmpForCvmVpn'
+
+# 对端网关不存在BGP ASN。
+UNSUPPORTEDOPERATION_VPNUNSUPPORTEDUSRGWNOTEXISTBGPASN = 'UnsupportedOperation.VpnUnsupportedUsrGwNotExistBgpAsn'
+
 # 指定资源在不同的可用区。
 UNSUPPORTEDOPERATION_ZONEMISMATCH = 'UnsupportedOperation.ZoneMismatch'
 
